==> haskell-brick-0.70-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brick
version:              0.70
visibility:           public
id:                   brick-0.70-ActL3lfpnpqCVYaiYFp5lZ
key:                  brick-0.70-ActL3lfpnpqCVYaiYFp5lZ
license:              BSD-3-Clause
copyright:            (c) Jonathan Daugherty 2015-2021
maintainer:           Jonathan Daugherty <cygnus@foobox.com>
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/brick/
synopsis:             A declarative terminal user interface library
description:
    Write terminal user interfaces (TUIs) painlessly with '\''brick'\''! You
    write an event handler and a drawing function and the library does the
    rest.


    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui


    To get started, see:

    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>

    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>

    * The demonstration programs in the '\''programs'\'' directory


    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.

category:             Graphics
abi:                  58d583591c1ca66fcf35390f6f20263d
exposed:              True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Themes Brick.Types Brick.Util
    Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Brick.Widgets.Table Data.IMap

hidden-modules:
    Brick.Types.Common Brick.Types.TH Brick.Types.Internal
    Brick.Widgets.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/brick-0.70
library-dirs:         /usr/lib/ghc-9.0.2/site-local/brick-0.70
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-brick
hs-libraries:         HSbrick-0.70-ActL3lfpnpqCVYaiYFp5lZ
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    config-ini-0.2.4.0-O1TjtuFKxvA0hXssYkojA containers-0.6.4.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    data-clist-0.2-9s8jX1ntXq637eBE7Fxeef deepseq-1.4.5.0
    directory-1.3.6.2 dlist-1.0-ImNlUre2rHgIkuGbqNQCOO
    exceptions-0.10.4 filepath-1.4.2.1
    microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI
    microlens-mtl-0.2.0.1-GerLHMFstYG6i4p3l30Z51
    microlens-th-0.4.3.10-CQmpaaSwO5aKTBUMVOAKZU stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0
    text-zipper-0.12-BnxkmHYbDqWKy45LsCHrNP transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.3.1-DWLcs41oUpGB6FR7Q3d3DL
    vty-5.36-5nswpts6HaPCvTZKq5QY26
    word-wrap-0.5-8LyIpzpRakKJMANIjMXdef

haddock-interfaces:   /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html:         /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.71-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brick
version:              0.71
visibility:           public
id:                   brick-0.71-7PXDoteXT3EAIiBEQY77YK
key:                  brick-0.71-7PXDoteXT3EAIiBEQY77YK
license:              BSD-3-Clause
copyright:            (c) Jonathan Daugherty 2015-2022
maintainer:           Jonathan Daugherty <cygnus@foobox.com>
author:               Jonathan Daugherty <cygnus@foobox.com>
homepage:             https://github.com/jtdaugherty/brick/
synopsis:             A declarative terminal user interface library
description:
    Write terminal user interfaces (TUIs) painlessly with '\''brick'\''! You
    write an event handler and a drawing function and the library does the
    rest.


    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui


    To get started, see:

    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>

    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>

    * The demonstration programs in the '\''programs'\'' directory


    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.

category:             Graphics
abi:                  532205da9337db8bfdd11ca92525afde
exposed:              True
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.BorderMap Brick.Focus
    Brick.Forms Brick.Main Brick.Themes Brick.Types Brick.Util
    Brick.Widgets.Border Brick.Widgets.Border.Style
    Brick.Widgets.Center Brick.Widgets.Core Brick.Widgets.Dialog
    Brick.Widgets.Edit Brick.Widgets.FileBrowser Brick.Widgets.List
    Brick.Widgets.ProgressBar Brick.Widgets.Table Data.IMap

hidden-modules:
    Brick.Types.Common Brick.Types.TH Brick.Types.Internal
    Brick.Widgets.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/brick-0.71
library-dirs:         /usr/lib/ghc-9.0.2/site-local/brick-0.71
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-brick
hs-libraries:         HSbrick-0.71-7PXDoteXT3EAIiBEQY77YK
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    config-ini-0.2.4.0-2Fqic5WQ0RjHIPdluu8Dcl containers-0.6.4.1
    contravariant-1.5.5-FtJyCLyWfutGN2UWoJs8qd
    data-clist-0.2-KOGE6Tg0mts4IEgKZj5BX6 deepseq-1.4.5.0
    directory-1.3.6.2 dlist-1.0-ImNlUre2rHgIkuGbqNQCOO
    exceptions-0.10.4 filepath-1.4.2.1
    microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI
    microlens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
    microlens-th-0.4.3.10-CQmpaaSwO5aKTBUMVOAKZU stm-2.5.0.0
    template-haskell-2.17.0.0 text-1.2.5.0
    text-zipper-0.12-HOKtA2jVOEV7wRavLfKy6p transformers-0.5.6.2
    unix-2.7.2.2 vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q
    vty-5.36-8uSPHIlBeGc4oX0N8Kts4Y
    word-wrap-0.5-IZM6oUGdKqx14CbKkxZBKM

haddock-interfaces:   /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html:         /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
